# encoding: utf-8
#
# Copyright 2016 Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.

from gs2_core_client.Gs2UserRequest import Gs2UserRequest
from gs2_showcase_client.Gs2Showcase import Gs2Showcase


class GetItemRequest(Gs2UserRequest):

    class Constant(Gs2Showcase):
        FUNCTION = "GetItem"

    def __init__(self, params=None):
        """
        コンストラクタ
        :param params: 辞書配列形式のパラメータ初期値リスト
        :type params: dict|None
        """
        super(GetItemRequest, self).__init__(params)
        if params is None:
            self.__showcase_name = None
            self.__showcase_item_id = None
        else:
            self.set_showcase_name(params['showcaseName'] if 'showcaseName' in params.keys() else None)
            self.set_showcase_item_id(params['showcaseItemId'] if 'showcaseItemId' in params.keys() else None)

    def get_showcase_name(self):
        """
        ショーケースの名前を取得
        :return: ショーケースの名前
        :rtype: unicode
        """
        return self.__showcase_name

    def set_showcase_name(self, showcase_name):
        """
        ショーケースの名前を設定
        :param showcase_name: ショーケースの名前
        :type showcase_name: unicode
        """
        if showcase_name and not (isinstance(showcase_name, str) or isinstance(showcase_name, unicode)):
            raise TypeError(type(showcase_name))
        self.__showcase_name = showcase_name

    def with_showcase_name(self, showcase_name):
        """
        ショーケースの名前を設定
        :param showcase_name: ショーケースの名前
        :type showcase_name: unicode
        :return: this
        :rtype: GetItemRequest
        """
        self.set_showcase_name(showcase_name)
        return self

    def get_showcase_item_id(self):
        """
        陳列商品のIDを取得
        :return: 陳列商品のID
        :rtype: unicode
        """
        return self.__showcase_item_id

    def set_showcase_item_id(self, showcase_item_id):
        """
        陳列商品のIDを設定
        :param showcase_item_id: 陳列商品のID
        :type showcase_item_id: unicode
        """
        if showcase_item_id and not (isinstance(showcase_item_id, str) or isinstance(showcase_item_id, unicode)):
            raise TypeError(type(showcase_item_id))
        self.__showcase_item_id = showcase_item_id

    def with_showcase_item_id(self, showcase_item_id):
        """
        陳列商品のIDを設定
        :param showcase_item_id: 陳列商品のID
        :type showcase_item_id: unicode
        :return: this
        :rtype: GetItemRequest
        """
        self.set_showcase_item_id(showcase_item_id)
        return self
